// https://nuxt.com/docs/api/configuration/nuxt-config
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { NaiveUiResolver } from 'unplugin-vue-components/resolvers'

export default defineNuxtConfig({
  srcDir: 'src',
  compatibilityDate: '2024-04-03',
  devtools: { enabled: true },
  css: [
    './src/assets/iconfont/iconfont.css',
    './src/assets/style/common.scss'
  ],
  sourcemap: {
    server: true,
    client: true
  },
  modules: [
    'nuxtjs-naive-ui',
    'nuxt-swiper',
    '@vueuse/nuxt',
    '@nuxtjs/tailwindcss',
    'nuxt-icons',
    '@nuxt/icon',
    'dayjs-nuxt',
    '@element-plus/nuxt',
    '@samk-dev/nuxt-vcalendar',
    [
      '@pinia/nuxt',
      {
        autoImports: ['defineStore', 'storeToRefs']
      }
    ]
  ],
  dayjs: {
    plugins: [
      'isSameOrAfter',
      'isSameOrBefore',
      'isToday',
      'customParseFormat',
      'minMax'
    ]
  },
  elementPlus: {
    defaultLocale: 'zh-cn',
    importStyle: 'scss'
  },
  runtimeConfig: {
    public: {
      baseApi: process.env.VITE_APP_BASE_URL,
      baseIM:process.env.VITE_APP_IM_URL
      // baseApi: '1234123'
    }
  },
  imports: {
    dirs: ['stores']
  },
  app: {
    head: {
      title: '逍遥游',
      meta: [
        {
          name: 'charset',
          content: 'utf-8'
        },
        {
          name: 'viewport',
          content: 'width=device-width,width=1250,maximum-scale=1.0'
        },
        {
          name: 'renderer',
          content: 'webkit'
        }
      ],
      link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.svg' }]
    }
  },
  vite: {
    css: {
      preprocessorOptions: {
        scss: {
          additionalData: '@use "@/assets/style/element.scss";',
        }
      }
    },
    plugins: [
      AutoImport({
        imports: [
          {
            'naive-ui': [
              'useDialog',
              'useMessage',
              'useNotification',
              'useLoadingBar'
            ]
          }
        ]
      }),
      Components({
        resolvers: [NaiveUiResolver()]
      })
    ]
  },
  devServer: {
    port: 3002
  }
})
